@@ -331,6 +331,10 @@ void DiagramScene::moveItems(QList<QGraphicsItem *> source, QPointF delta)
             if(!item->parentItem()->isSelected()) item->moveBy(delta.x(),delta.y());
         }
         else {
+            if(item->type()==DiagramTextItem::Type){
+                auto *textItem=qgraphicsitem_cast<DiagramTextItem*>(item);
+                textItem->setAnchorPoint(textItem->anchorPoint()+delta);
+            }
             item->moveBy(delta.x(),delta.y());
         }
     }
@@ -728,8 +732,8 @@ void DiagramScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
             qreal dy=point.ry()-myDy;
             moveItems(copiedItems,QPointF(dx,dy));
             // place copy of the items and keep the currents items in copyList
-            copyItems(copiedItems);
             takeSnapshot();
+            copyItems(copiedItems);
         }
         if(middleButton){
             // switch toolbar !!
@@ -1029,8 +1033,19 @@ QGraphicsItem* DiagramScene::copy(QGraphicsItem* item)
     }
         break;
     case DiagramPathItem::Type:
-        return qgraphicsitem_cast<QGraphicsItem*>(qgraphicsitem_cast<DiagramPathItem*>(item)->copy());
+    {
+        DiagramPathItem* newItem=qgraphicsitem_cast<DiagramPathItem*>(item)->copy();
+        if(item->childItems().count()>0){
+            foreach(QGraphicsItem* item_l1,item->childItems()){
+                QGraphicsItem* addedItem=copy(item_l1);
+                addItem(addedItem);
+                addedItem->setParentItem(newItem);
+                addedItem->setPos(item_l1->pos());
+            }
+        }
+        return qgraphicsitem_cast<QGraphicsItem*>(newItem);
         break;
+    }
     case DiagramSplineItem::Type:
         return qgraphicsitem_cast<QGraphicsItem*>(qgraphicsitem_cast<DiagramSplineItem*>(item)->copy());
         break;
